@@ -49,12 +49,15 @@ class Agent(Addressable, AbstractAgent):
         self.__migrate()
 
     def __send_genotype(self):
-        if random.random() < 0.01:
+        if random.random() < 0.05:
             try:
                 neighbour = self.locator.get_neighbour(self)
                 if neighbour:
                     logger.debug("neighbour: %s", neighbour.get_address())
-                    probe = list(self.population.sort(key=lambda g: g.fitness))[:20:2]
+                    self.population.sort
+                    sorted_population = list(self.population)
+                    sorted_population.sort(key=lambda g: g.fitness)
+                    probe = sorted_population[:20:2]
                     neighbour.add_genotype(probe)
             except:
                 logging.exception('')
@@ -62,6 +65,7 @@ class Agent(Addressable, AbstractAgent):
     def __migrate(self):
         self.migration.migrate(self)
 
+
 class AggregateAgent(Addressable, AbstractAgent):
     @Inject("aggregated_agents:_AggregateAgent__agents")
     def __init__(self, name=None):
@@ -106,6 +110,17 @@ def agents_factory(*args):
     return factory
 
 
+def generate_agents(prefix, count, type):
+    def factory():
+        agents = {}
+        for i in range(count):
+            agent = type(prefix + str(i))
+            agents[agent.get_address()] = agent
+        return agents
+
+    return factory
+
+
 def aggregate_agents_factory(*args):
     def factory():
         agents = {}
@@ -115,3 +130,4 @@ def aggregate_agents_factory(*args):
         return agents
 
     return factory
+
