@@ -1,7 +1,7 @@
 from datetime import datetime
 import logging
 import threading
-from time import sleep
+from time import sleep, time
 import Pyro4
 import sys
 from pyage.core import inject
@@ -10,6 +10,7 @@ from pyage.core.workspace import Workspace
 logger = logging.getLogger(__name__)
 
 if __name__ == '__main__':
+    start_time = time()
     logging.basicConfig(filename='pyage-' + str(datetime.now()) + '.log', level=logging.DEBUG)
     inject.config = sys.argv[1]
     logging.debug("config: %s", inject.config)
@@ -27,5 +28,6 @@ if __name__ == '__main__':
             sleep(float(sys.argv[2]))
         except IndexError:
             pass
+    logger.debug("elapsed time: %s seconds",time() - start_time)
     workspace.daemon.close()
 
